<html>
<head>
<title>Django Okta app sample</title>
</head>
<body>
<h1>Django Okta app sample</h1>
<h3>This is a simple page to "run" the Django Okta app.</h3>
<p>Here's some sample/useless text:</p>
<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Pharetra diam sit amet nisl suscipit adipiscing bibendum est ultricies. Iaculis at erat pellentesque adipiscing. Habitant morbi tristique senectus et. Molestie at elementum eu facilisis sed. Enim sit amet venenatis urna cursus eget. Elit scelerisque mauris pellentesque pulvinar pellentesque. Odio facilisis mauris sit amet massa. Sem et tortor consequat id porta. Cum sociis natoque penatibus et magnis dis parturient. Faucibus pulvinar elementum integer enim neque volutpat. Erat imperdiet sed euismod nisi porta lorem. Viverra adipiscing at in tellus integer. Amet venenatis urna cursus eget. Porttitor eget dolor morbi non arcu risus quis varius. Volutpat sed cras ornare arcu dui vivamus. Enim eu turpis egestas pretium aenean pharetra. Id neque aliquam vestibulum morbi blandit cursus risus at ultrices. Interdum consectetur libero id faucibus nisl tincidunt.</p>
<p>Diam donec adipiscing tristique risus nec feugiat in fermentum. Rutrum quisque non tellus orci ac auctor augue mauris augue. Quis ipsum suspendisse ultrices gravida dictum. Fermentum iaculis eu non diam phasellus vestibulum lorem. Tristique sollicitudin nibh sit amet commodo nulla facilisi nullam vehicula. A arcu cursus vitae congue mauris rhoncus aenean. Viverra ipsum nunc aliquet bibendum enim facilisis. Adipiscing diam donec adipiscing tristique risus nec feugiat in fermentum. Nunc lobortis mattis aliquam faucibus purus. Integer quis auctor elit sed vulputate mi sit. Mattis aliquam faucibus purus in massa tempor nec feugiat nisl. Donec massa sapien faucibus et. In tellus integer feugiat scelerisque. Ut placerat orci nulla pellentesque dignissim enim sit amet venenatis. Egestas diam in arcu cursus euismod quis viverra nibh. Leo in vitae turpis massa sed elementum tempus. Semper eget duis at tellus at urna condimentum mattis. Urna condimentum mattis pellentesque id nibh tortor id.</p>
<p>Pellentesque massa placerat duis ultricies. Egestas diam in arcu cursus euismod. Ut enim blandit volutpat maecenas volutpat blandit aliquam. Augue lacus viverra vitae congue eu consequat ac felis donec. Odio aenean sed adipiscing diam donec adipiscing tristique risus nec. Neque sodales ut etiam sit. Quam viverra orci sagittis eu volutpat odio facilisis mauris. Tellus id interdum velit laoreet id donec ultrices tincidunt arcu. Blandit libero volutpat sed cras ornare arcu dui vivamus. Mauris nunc congue nisi vitae suscipit tellus mauris a diam. Pharetra et ultrices neque ornare aenean euismod elementum nisi. Ultrices neque ornare aenean euismod elementum nisi quis eleifend. Libero nunc consequat interdum varius sit amet mattis vulputate enim. Sit amet nisl purus in mollis. Et tortor consequat id porta. Pretium vulputate sapien nec sagittis aliquam malesuada bibendum arcu vitae.</p>
<p>Vitae justo eget magna fermentum iaculis eu non. Mi tempus imperdiet nulla malesuada. Mauris cursus mattis molestie a iaculis at. Eget est lorem ipsum dolor sit amet. Lectus mauris ultrices eros in cursus turpis. Euismod elementum nisi quis eleifend quam adipiscing vitae proin sagittis. Pretium lectus quam id leo. Dictum non consectetur a erat nam. Et leo duis ut diam quam nulla porttitor massa id. Sed viverra ipsum nunc aliquet bibendum enim. Amet risus nullam eget felis eget nunc lobortis mattis aliquam. Nullam eget felis eget nunc lobortis mattis aliquam faucibus purus. Lectus vestibulum mattis ullamcorper velit sed ullamcorper morbi tincidunt ornare.</p>
<p>Lorem sed risus ultricies tristique nulla aliquet enim. Cras fermentum odio eu feugiat pretium nibh ipsum consequat. Ipsum nunc aliquet bibendum enim facilisis. Id diam vel quam elementum pulvinar etiam. Morbi non arcu risus quis varius quam quisque. Sed nisi lacus sed viverra tellus. Imperdiet proin fermentum leo vel orci. Quam nulla porttitor massa id neque. Morbi tristique senectus et netus et malesuada fames. Vulputate mi sit amet mauris commodo quis imperdiet massa tincidunt. Senectus et netus et malesuada fames ac turpis egestas. Tincidunt lobortis feugiat vivamus at augue eget. Vulputate eu scelerisque felis imperdiet proin.</p>
</body>
</html>
